@@ -19,5 +19,5 @@ def dice_loss_binary(outputs=None, target=None, beta=1, weights=None):
     tflat = target.contiguous().float().view(-1)
     intersection = (iflat * tflat * w).sum()
 
-    return (((1 + beta ** 2) * intersection) + smooth) / (
+    return 1. - (((1 + beta ** 2) * intersection) + smooth) / (
             ((beta ** 2 * (w * iflat).sum()) + (w * tflat).sum()) + smooth)
